@@ -14,8 +14,9 @@ use AWS::Signature4;
 use HTTP::Request::Common;
 use Amazon::SNS::V4::Target;
 use Amazon::SNS::V4::Topic;
+use Amazon::SNS::V4::FifoTopic;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 
 sub CreateTopic
@@ -35,6 +36,9 @@ sub CreateTopic
 sub GetTopic
 {
 	my ($self, $arn) = @_;
+	if ($arn =~ m{\.fifo$}) {
+		return GetFifoTopic( @_ );
+	}
 
 	return Amazon::SNS::V4::Topic->new({
 		'sns' => $self,
@@ -42,6 +46,16 @@ sub GetTopic
 	});
 }
 
+sub GetFifoTopic
+{
+	my ($self, $arn) = @_;
+
+	return Amazon::SNS::V4::FifoTopic->new({
+		'sns' => $self,
+		'arn' => $arn,
+	});
+}
+
 sub GetTarget
 {
 	my ($self, $arn) = @_;
@@ -199,6 +213,11 @@ Amazon::SNS::V4 - Amazon Simple Notification Service with v4 Signatures
 
   $topic->Publish('My test message', 'My Subject');
 
+  # publish to a known ARN (FIFO)
+
+  my $topic = $sns->GetTopic('arn:aws:sns:eu-west-1:123456789099:MyTopic.fifo');
+
+  $topic->Publish('My test message', 'My Subject', 'group-id', 'dedupe-id');
 
   # get all topics
 
@@ -206,11 +225,9 @@ Amazon::SNS::V4 - Amazon Simple Notification Service with v4 Signatures
 
   print $_->arn, "\n" for @topics;
 
-
-
   # change region
 
-  $sns->service('http://sns.us-east-1.amazonaws.com');
+  $sns->service('https://sns.us-east-1.amazonaws.com');
 
 =head1 DESCRIPTION
 
